==> qtjambi-qt3drender-6.5.7-sources.jar: io/qt/qt3d/render/QTexture2DMultisampleArray.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>A QAbstractTexture with a Target2DMultisampleArray target format</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qtexture2dmultisamplearray.html">Qt3DRender::QTexture2DMultisampleArray</a></code></p>
 */
public class QTexture2DMultisampleArray extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTexture2DMultisampleArray.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtexture2dmultisamplearray.html#QTexture2DMultisampleArray">Qt3DRender::QTexture2DMultisampleArray::<wbr/>QTexture2DMultisampleArray(Qt3DCore::QNode*)</a></code></p>
     */
    @SuppressWarnings({"exports"})
    public QTexture2DMultisampleArray(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTexture2DMultisampleArray instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QTexture2DMultisampleArray(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QTexture2DMultisampleArray(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QTexture2DMultisampleArray instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTexture2DMultisampleArray(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTexture2DMultisampleArray() {
        this((io.qt.qt3d.core.QNode)null);
    }
}

==> qtjambi-qt3drender-6.6.0-sources.jar: io/qt/qt3d/render/QTexture2DMultisampleArray.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>A QAbstractTexture with a Target2DMultisampleArray target format</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qtexture2dmultisamplearray.html">Qt3DRender::QTexture2DMultisampleArray</a></code></p>
 */
public class QTexture2DMultisampleArray extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTexture2DMultisampleArray.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtexture2dmultisamplearray.html#QTexture2DMultisampleArray">Qt3DRender::QTexture2DMultisampleArray::<wbr>QTexture2DMultisampleArray(Qt3DCore::QNode*)</a></code></p>
     */
    @SuppressWarnings({"exports"})
    public QTexture2DMultisampleArray(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTexture2DMultisampleArray instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QTexture2DMultisampleArray(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QTexture2DMultisampleArray(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QTexture2DMultisampleArray instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTexture2DMultisampleArray(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTexture2DMultisampleArray() {
        this((io.qt.qt3d.core.QNode)null);
    }
}
